package com.sincere.wechatbusiness.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.sincere.wechatbusiness.dto.BaseDto;
import com.sincere.wechatbusiness.dto.ChannelDto;
import com.sincere.wechatbusiness.dto.CopyDto;
import com.sincere.wechatbusiness.logs.LogName;
import com.sincere.wechatbusiness.logs.LoggerUtils;
import com.sincere.wechatbusiness.model.*;
import com.sincere.wechatbusiness.service.*;
import com.sincere.wechatbusiness.utils.Page;
import com.sincere.wechatbusiness.utils.TokenUtils;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.*;

@RestController
public class ChannelController {
    @Autowired
    ChannelService channelService;

    @Autowired
    ChannelProductService channelProductService;

    @Autowired
    BannerService bannerService;

    @Autowired
    AttentionService attentionService;

    @Autowired
    CatalogService catalogService;

    @Autowired
    CatalogContentService catalogContentService;

    @Autowired
    AgentService agentService;

    @Autowired
    PageViewService pageViewService ;

    private static final Logger log_channel = LoggerUtils.Logger(LogName.channel);

    @Value("${reportVoluntary}")
    private String domain;

    private static String appId = "wx6078ff3f67524996";
    private static String secret = "8a0465b8ad0f000f568f48853e2818c8" ;

    @RequestMapping(value = "getByTemplate",method = RequestMethod.GET)
    @ApiOperation(value = "获取统一模板下 渠道商")
    public BaseDto<List<Channel>> getByTemplate(int templateId){
        Channel channel = channelService.getDetail(templateId);
        BaseDto<List<Channel>> result = new BaseDto<>();
        result.setData(channelService.getListByTemplate(channel.getTemplateId()));
        return result ;
    }

    @RequestMapping(value = "copyChannel",method = RequestMethod.POST)
    @ApiOperation(value = "内容下发")
    public BaseDto copyChannel(@RequestBody CopyDto copyDto){
        Channel channel = channelService.getDetail(copyDto.getSourceId());
        if(channel.getTemplateId() == 1){
            List<Banner> banners = bannerService.getList(copyDto.getSourceId());
            Attention attention = attentionService.getDetail(copyDto.getSourceId());
            List<Catalog> catalogs = catalogService.getList(copyDto.getSourceId());
            for(Integer channelId : copyDto.getTargetIdList()){
                bannerService.deleteChannelBanner(channelId);
                for(Banner banner : banners){
                    banner.setChannelId(channelId);
                    bannerService.copy(banner);
                }
                attentionService.deleteAttention(channelId);
                if(attention != null){
                    attention.setChannelId(channelId);
                    attentionService.insert(attention);
                }
                catalogService.deleteCatalog(channelId);
                for(Catalog catalog : catalogs){
                    catalog.setChannelId(channelId);
                    catalogService.insert(catalog);
                    List<CatalogContent> list = catalogContentService.getList(catalog.getId());
                    for(CatalogContent catalogContent : list){
                        catalogContent.setCatalogId(catalog.getId());
                        catalogContentService.insert(catalogContent);
                    }
                }
            }
        }else if(channel.getTemplateId() == 2 || channel.getTemplateId() == 3){
            List<Banner> banners = bannerService.getList(copyDto.getSourceId());
            List<BannerNext> bannerNexts = bannerService.getBannerNextList(copyDto.getSourceId());
            for(Integer channelId : copyDto.getTargetIdList()){
                bannerService.deleteChannelBanner(channelId);
                bannerService.deleteChannelBannerNext(channelId);
                for(Banner banner : banners){
                    banner.setChannelId(channelId);
                    bannerService.copy(banner);
                }
                for(BannerNext bannerNext : bannerNexts){
                    bannerNext.setChannelId(channelId);
                    bannerService.copyBannerNext(bannerNext);
                }
            }
        }else if(channel.getTemplateId() == 4){
            List<Banner> banners = bannerService.getList(copyDto.getSourceId());
            for(Integer channelId : copyDto.getTargetIdList()){
                bannerService.deleteChannelBanner(channelId);
                for(Banner banner : banners){
                    banner.setChannelId(channelId);
                    bannerService.copy(banner);
                }
            }
        }
        return new BaseDto();
    }


    @RequestMapping(value = "updateLook",method = RequestMethod.POST)
    @ApiOperation(value = "增加浏览量")
    public BaseDto updateLook(@RequestBody PageView pageView){
        pageViewService.updateLook(pageView);
        return new BaseDto();
    }

    @RequestMapping(value = "getBannerNextList",method = RequestMethod.GET)
    @ApiOperation(value = "获取左右轮播图列表")
    public BaseDto<List<BannerNext>> getBannerNextList(int channelId){
        BaseDto<List<BannerNext>> result = new BaseDto<>();
        result.setData(bannerService.getBannerNextList(channelId));
        return result ;
    }

    @RequestMapping(value = "insertBannerNext",method = RequestMethod.POST)
    @ApiOperation(value = "新增左右轮播图")
    public BaseDto insertBannerNext(@RequestBody BannerNext bannerNext){
        bannerService.insertBannerNext(bannerNext);
        return new BaseDto();
    }

    @RequestMapping(value = "updateBannerNext",method = RequestMethod.POST)
    @ApiOperation(value = "修改左右轮播图")
    public BaseDto updateBannerNext(@RequestBody BannerNext bannerNext){
        bannerService.update(bannerNext);
        return new BaseDto();
    }

    @RequestMapping(value = "deleteBannerNext",method = RequestMethod.GET)
    @ApiOperation(value = "删除左右轮播图")
    public BaseDto deleteBannerNext(int id){
        bannerService.deleteBannerNext(id);
        return new BaseDto();
    }

    @RequestMapping(value = "GetChannelList",method = RequestMethod.POST)
    @ApiOperation(value = "获取渠道商列表")
    public BaseDto<Page<Channel>> GetChannelList(@RequestBody ChannelDto channelDto){
        BaseDto<Page<Channel>> result=new BaseDto<>();
        Channel channel=new Channel();
        channel.setName(channelDto.getName());
        channel.setState(1);
        result.setData(channelService.getList(channel,channelDto.getPage(),channelDto.getPageSize()));
        return result;
    }

    @RequestMapping(value="GetAreaList",method = RequestMethod.POST)
    @ApiOperation(value = "获取省市")
    public BaseDto<List<Area>> GetAreaList(){
        BaseDto<List<Area>> result=new BaseDto<>();
        result.setData(channelService.getAreaList());
        return result;
    }

    @RequestMapping(value = "GetTemplateList",method = RequestMethod.POST)
    @ApiOperation(value = "获取模板库列表")
    public BaseDto<List<Template>> GetTemplateList(){
        BaseDto<List<Template>> result=new BaseDto<>();
        result.setData(channelService.getTemplateList());
        return result;
    }

    @RequestMapping(value = "AddChannel",method = RequestMethod.POST)
    @ApiOperation(value = "新增渠道商")
    public BaseDto AddChannel(@RequestBody Channel channel){
        channelService.insert(channel);
        if(channel.getChannelProductList()!=null&&channel.getChannelProductList().size()>0) {
            for(ChannelProduct channelProduct:channel.getChannelProductList()){
                channelProduct.setChannelId(channel.getId());
                String r=Get(domain+"/University/getPackageById","id="+channelProduct.getProductId());
                JSONObject jsonObject= JSONObject.parseObject(r);
                String data = jsonObject.getString("data");
                DiscountPackage model=JSON.parseObject(data,new TypeReference<DiscountPackage>(){});
                channelProduct.setChannelTitle(model.getPackage_name());
                channelProduct.setChannelImg(model.getPhoto());
                channelProduct.setChannelRequire(model.getDescribe());
                channelProduct.setChannelExplain(model.getRequire());
                channelProductService.insert(channelProduct);
            }
        }
        return new BaseDto();
    }

    @RequestMapping(value = "GetChannelProductList",method = RequestMethod.GET)
    @ApiOperation(value = "获取渠道商代理商品列表")
    public BaseDto<List<ChannelProduct>> GetChannelProductList(int id){
        BaseDto<List<ChannelProduct>> result=new BaseDto<>();
        result.setData(channelProductService.getList(id));
        return result;
    }

    @RequestMapping(value = "GetChannelDetail",method = RequestMethod.GET)
    @ApiOperation(value = "获取渠道商详情")
    public BaseDto<Channel> GetChannelDetail(int id){
        BaseDto<Channel> result=new BaseDto<>();
        Channel channel=channelService.getDetail(id);
        channel.setChannelProductList(channelProductService.getList(id));
        result.setData(channel);
        return result;
    }

    @RequestMapping(value = "UpdateChannel",method = RequestMethod.POST)
    @ApiOperation(value = "编辑渠道商")
    public BaseDto UpdateChannel(@RequestBody Channel channel){
        channelService.update(channel);
        if(channel.getChannelProductList()!=null&&channel.getChannelProductList().size()>0){
            channelProductService.deleteChannelProduct(channel.getId());
            for (ChannelProduct channelProduct:channel.getChannelProductList()){
                channelProduct.setChannelId(channel.getId());
                channelProductService.insert(channelProduct);
            }
        }
        return new BaseDto();
    }


    @RequestMapping(value = "DeleteChannel",method = RequestMethod.GET)
    @ApiOperation(value = "删除渠道商")
    public BaseDto DeleteChannel(int id){
        channelService.deleteChannel(id);
        return new BaseDto();
    }

    @RequestMapping(value = "getChannelProduct",method = RequestMethod.GET)
    @ApiOperation(value = "渠道商商品详情")
    public BaseDto<ChannelProduct> getChannelProduct(int id){
        BaseDto<ChannelProduct> result = new BaseDto<>();
        result.setData(channelProductService.getDetail(id));
        return result;
    }

    @RequestMapping(value = "UpdateChannelProduct",method = RequestMethod.POST)
    @ApiOperation(value = "编辑代理商品")
    public BaseDto UpdateChannelProduct(@RequestBody ChannelProduct channelProduct){
        channelProductService.update(channelProduct);
        return new BaseDto();
    }

    @RequestMapping(value = "UpdateChannelProductMsg",method = RequestMethod.POST)
    @ApiOperation(value = "编辑代理商品详情")
    public BaseDto UpdateChannelProductMsg(@RequestBody ChannelProduct channelProduct){
        channelProductService.updateChannelProductMsg(channelProduct);
        return new BaseDto();
    }

    @RequestMapping(value = "GetBannerList",method = RequestMethod.GET)
    @ApiOperation(value = "获取Banner轮播图列表")
    public BaseDto<List<Banner>> GetBannerList(int id){
        BaseDto<List<Banner>> result=new BaseDto<>();
        result.setData(bannerService.getList(id));
        return result;
    }

    @RequestMapping(value = "AddBanner",method = RequestMethod.POST)
    @ApiOperation(value = "添加Banner轮播图")
    public BaseDto AddBanner(@RequestBody Banner banner){
        bannerService.insert(banner);
        return new BaseDto();
    }

    @RequestMapping(value = "UpdateBanner",method = RequestMethod.POST)
    @ApiOperation(value = "编辑Banner轮播图")
    public BaseDto UpdateBanner(@RequestBody Banner banner){
        bannerService.update(banner);
        return new BaseDto();
    }

    @RequestMapping(value = "DeleteBanner",method = RequestMethod.GET)
    @ApiOperation(value = "删除Banner轮播图")
    public BaseDto DeleteBanner(int id){
        bannerService.deleteBanner(id);
        return new BaseDto();
    }

    @RequestMapping(value = "GetAttention",method = RequestMethod.GET)
    @ApiOperation(value = "获取关注配置")
    public BaseDto<Attention> GetAttention(int id){
        BaseDto<Attention> result=new BaseDto<>();
        result.setData(attentionService.getDetail(id));
        return result;
    }

    @RequestMapping(value = "AddAttention",method = RequestMethod.POST)
    @ApiOperation(value = "添加关注配置")
    public BaseDto AddAttention(@RequestBody Attention attention){
        attentionService.insert(attention);
        return new BaseDto();
    }

    @RequestMapping(value = "UpdateAttention",method = RequestMethod.POST)
    @ApiOperation(value = "编辑关注配置")
    public BaseDto UpdateAttention(@RequestBody Attention attention){
        attentionService.update(attention);
        return new BaseDto();
    }

    @RequestMapping(value = "GetCatalog",method = RequestMethod.GET)
    @ApiOperation(value = "获取栏目")
    public BaseDto<Catalog> GetCatalog(int channelId,int sort){
        BaseDto<Catalog> result=new BaseDto<>();
        Catalog catalog=new Catalog();
        catalog.setChannelId(channelId);
        catalog.setSort(sort);
        catalog=catalogService.getDetail(catalog);
        if(catalog!=null) catalog.setCatalogContentList(catalogContentService.getList(catalog.getId()));
        result.setData(catalog);
        return result;
    }

    @RequestMapping(value = "AddCatalog",method = RequestMethod.POST)
    @ApiOperation(value = "新增栏目")
    public BaseDto AddCatalog(@RequestBody Catalog catalog){
        catalogService.insert(catalog);
        return new BaseDto();
    }

    @RequestMapping(value = "UpdateCatalog",method = RequestMethod.POST)
    @ApiOperation(value = "编辑栏目")
    public BaseDto UpdateCatalog(@RequestBody Catalog catalog){
        catalogService.update(catalog);
        return new BaseDto();
    }

    @RequestMapping(value = "AddCatalogContent",method = RequestMethod.POST)
    @ApiOperation(value = "新增栏目内容")
    public BaseDto AddCatalogContent(@RequestBody CatalogContent catalogContent){
        catalogContentService.insert(catalogContent);
        return new BaseDto();
    }

    @RequestMapping(value = "UpdateCatalogContent",method = RequestMethod.POST)
    @ApiOperation(value = "编辑栏目内容")
    public BaseDto UpdateCatalogContent(@RequestBody CatalogContent catalogContent){
        catalogContentService.update(catalogContent);
        return new BaseDto();
    }

    @RequestMapping(value = "DeleteCatalogContent",method = RequestMethod.GET)
    @ApiOperation(value = "删除栏目内容")
    public BaseDto DeleteCatalogContent(int id){
        catalogContentService.deleteCatalogContent(id);
        return new BaseDto();
    }

    @RequestMapping(value = "GetAgentList",method = RequestMethod.GET)
    @ApiOperation(value = "获取推广代理列表")
    public BaseDto<List<Agent>> GetAgentList(int id){
        BaseDto<List<Agent>> result=new BaseDto<>();
        result.setData(agentService.getList(id));
        return result;
    }

    @RequestMapping(value = "AddAgent",method = RequestMethod.POST)
    @ApiOperation(value = "新增推广代理")
    public BaseDto AddAgent(@RequestBody Agent agent){
        agentService.insert(agent);
        return new BaseDto();
    }

    @RequestMapping(value = "UpdateAgent",method = RequestMethod.POST)
    @ApiOperation(value = "编辑推广代理")
    public BaseDto UpdateAgent(@RequestBody Agent agent){
        agentService.update(agent);
        return new BaseDto();
    }

    @RequestMapping(value = "DeleteAgent",method = RequestMethod.GET)
    @ApiOperation(value = "删除推广代理")
    public BaseDto DeleteAgent(int id){
        agentService.deleteAgent(id);
        return new BaseDto();
    }

    @RequestMapping(value = "GetCatalogList",method = RequestMethod.GET)
    @ApiOperation(value = "获取栏目列表")
    public BaseDto<List<Catalog>> GetCatalogList(int id){
        BaseDto<List<Catalog>> result=new BaseDto<>();
        result.setData(catalogService.getList(id));
        return result;
    }

    @RequestMapping(value = "GetCatalogContByDate",method = RequestMethod.GET)
    @ApiOperation(value ="根据日期获取栏目内容" )
    public BaseDto<List<CatalogContent>> GetCatalogContByDate(int catalogId,String date){
        BaseDto<List<CatalogContent>> result=new BaseDto<>();
        result.setData(catalogContentService.getListByDate(catalogId,date));
        return result;
    }

    @RequestMapping(value = "GetChannelProduct",method = RequestMethod.GET)
    @ApiOperation(value = "获取代理商品详情")
    public BaseDto<ChannelProduct> GetChannelProduct(int id){
        BaseDto<ChannelProduct> result=new BaseDto<>();
        result.setData(channelProductService.getDetail(id));
        return result;
    }

    @RequestMapping(value = "openAddress",method = RequestMethod.GET)
    @ApiOperation(value = "开启配送，或者关闭配送")
    public BaseDto openAddress(int id){
        ChannelProduct channelProduct = channelProductService.getDetail(id);
        channelProductService.updateProductOpenAddress(channelProduct.getOpenAddress()==1?0:1,id);
        return new BaseDto();
    }

    @RequestMapping(value = "GetWxSign",method = RequestMethod.GET)
    @ApiOperation(value = "获取微信分享签名")
    public BaseDto<WxSign> GetWxSign(String url){
        try {
            url = java.net.URLDecoder.decode(url, "UTF-8");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        url=url.replaceAll("\\+", "%2B");
        BaseDto<WxSign> result=new BaseDto<>();

        WxSign wxSign1=new WxSign();
        wxSign1.setTimestamp(Long.toString(System.currentTimeMillis()));
        wxSign1.setNoncestr(UUID.randomUUID().toString());
        AccessToken accessToken=channelService.getAccessToken();
        Token token=new Token();
        if(accessToken!=null) {
            Calendar dateOne=Calendar.getInstance();
            Calendar dateTwo=Calendar.getInstance();
            dateOne.setTime(new Date());
            dateTwo.setTime(accessToken.getCreateTime());
            long timeOne=dateOne.getTimeInMillis();
            long timeTwo=dateTwo.getTimeInMillis();
            long minute=(timeOne-timeTwo)/(1000*60);

            if(minute<60) token.setAccess_token(accessToken.getAccessToken());
            else{
                token=getAccessToken(appId,secret);
                accessToken.setAccessToken(token.getAccess_token());
                channelService.insertAccessToken(accessToken);
            }
        }
        else {
            token=getAccessToken(appId,secret);
            accessToken=new AccessToken();
            accessToken.setAccessToken(token.getAccess_token());
            channelService.insertAccessToken(accessToken);
        }
        String js=Get("https://api.weixin.qq.com/cgi-bin/ticket/getticket","type=jsapi&access_token="+token.getAccess_token());
        JSONObject jsonObject= JSONObject.parseObject(js);
        log_channel.info("获取ticket返回数据----"+jsonObject.toJSONString());
        if(jsonObject.getString("errcode").equals("40001")){
            //token 过期 重新获取
            token=getAccessToken(appId,secret);
            accessToken=new AccessToken();
            accessToken.setAccessToken(token.getAccess_token());
            channelService.insertAccessToken(accessToken);
            js=Get("https://api.weixin.qq.com/cgi-bin/ticket/getticket","type=jsapi&access_token="+token.getAccess_token());
            jsonObject= JSONObject.parseObject(js);
        }
        wxSign1.setJsapi_ticket(jsonObject.getString("ticket"));
        String rawstring = "jsapi_ticket=" + wxSign1.getJsapi_ticket() + "&noncestr=" + wxSign1.getNoncestr() + "&timestamp=" + wxSign1.getTimestamp() + "&url=" + url + "";
        wxSign1.setSignature(SHA1(rawstring));
        result.setData(wxSign1);
        return result;
    }


    @RequestMapping(value = "AdminLogin",method = RequestMethod.GET)
    @ApiOperation(value = "管理员登录")
    public BaseDto<String> AdminLogin(String mobile){
        BaseDto<String> result=new BaseDto();
        Manager manager=channelService.getManagerDetail(mobile);
        if(manager==null){
            result.setSuccess(false);
            result.setMessage("账号不存在！");
        }
        Log log=new Log();
        log.setOperation("账号登录");
        log.setMobile(mobile);
        channelService.insertLog(log);
        result.setData(TokenUtils.buildToken(mobile));
        return result;
    }

    @RequestMapping(value = "GetToken",method = RequestMethod.GET)
    @ApiOperation(value = "获取openid")
    public BaseDto<Token> GetToken(String code){
        BaseDto<Token> result=new BaseDto<>();
        String re=Get("http://campus.myjxt.com/api/EasyMessage/GetTokenYKT","code="+code);
        JSONObject jsonObject1= JSONObject.parseObject(re);
        String data1 = jsonObject1.getString("data");
        result.setData(JSON.parseObject(data1,new TypeReference<Token>(){}));
        return result;
    }

    @RequestMapping(value = "GetStatistics",method = RequestMethod.GET)
    @ApiOperation(value = "获取渠道商统计，type：1-今日；2-本月；3-累计")
    public BaseDto<List<Statistics>> GetStatistics(int channelId,int agentId,int type){
        BaseDto<List<Statistics>> result=new BaseDto();
        List<Statistics> list=new ArrayList<>();
        Statistics pageView=new Statistics();
        pageView.setCount(channelService.getPageViewCount(channelId,agentId,type));
        List<Users> pageViewList=new ArrayList<>();
        Users channelPageView =channelService.getChannelPageView(channelId,type) ;
        if(channelPageView != null){
            pageViewList.add(channelPageView);
        }
        pageViewList.addAll(channelService.getAgentPageViewList(channelId,0,type));
        pageView.setUsersList(pageViewList);
        list.add(pageView);
        Statistics register=new Statistics();
        register.setCount(channelService.getRegisterCount(channelId,agentId,type));
        List<Users> registerList=new ArrayList<>();
        Users channelRegister=new Users();
        channelRegister=channelService.getChannelRegister(channelId,type);
        if(channelRegister!=null) registerList.add(channelRegister);
        registerList.addAll(channelService.getAgentRegisterList(channelId,type));
        register.setUsersList(registerList);
        list.add(register);
        Statistics order=new Statistics();
        order.setCount(channelService.getOrderCount(channelId,agentId,type));
        List<Users> orderList=new ArrayList<>();
        Users channelOrder=new Users();
        channelOrder=channelService.getChannelOrder(channelId,type);
        if(channelOrder!=null) orderList.add(channelOrder);
        orderList.addAll(channelService.getAgentOrderList(channelId,type));
        order.setUsersList(orderList);
        list.add(order);
        Statistics statistics=new Statistics();
        statistics.setDiscountPackageList(channelService.getOrderList(channelId,agentId,type));
        list.add(statistics);
        result.setData(list);
        return result;
    }

    @RequestMapping(value = "GetStatisticsRegisterDetailList",method = RequestMethod.GET)
    @ApiOperation(value = "获取注册详情")
    public BaseDto<List<Users>> GetStatisticsRegisterDetailList(int channelId,int agentId,int type){
        BaseDto<List<Users>> result=new BaseDto<>();
        result.setData(channelService.getRegisterDetailList(channelId,agentId,type));
        return result;
    }

    @RequestMapping(value = "GetStatisticsOrderDetailList",method = RequestMethod.GET)
    @ApiOperation(value = "获取订购详情")
    public BaseDto<List<DiscountPackage>> GetStatisticsOrderDetailList(int channelId,int agentId,int type,int productId){
        BaseDto<List<DiscountPackage>> result=new BaseDto<>();
        List<DiscountPackage> packageList = new ArrayList<>();
        packageList.addAll(channelService.getOrderDetailList(channelId,agentId,type,productId));
        if(agentId == 0){
            List<Agent> agents = agentService.getList(channelId);
            for(Agent agent : agents){
                packageList.addAll(channelService.getOrderDetailList(channelId,agent.getId(),type,productId));
            }
        }
        result.setData(packageList);
        return result;
    }

    @RequestMapping(value = "GetAgentStatistics",method = RequestMethod.GET)
    @ApiOperation(value = "获取推广统计，type：1-今日；2-本月；3-累计")
    public BaseDto<List<Statistics>> GetAgentStatistics(int channelId,int agentId,int type){
        BaseDto<List<Statistics>> result=new BaseDto<>();
        List<Statistics> list=new ArrayList<>();
        Statistics pageView=new Statistics();
        pageView.setCount(channelService.getPageViewCount(channelId,agentId,type));
        pageView.setUsersList(channelService.getAgentPageViewList(channelId,agentId,type));
        list.add(pageView);

        Statistics register=new Statistics();
        register.setCount(channelService.getRegisterCount(channelId,agentId,type));
        register.setUsersList(channelService.getRegisterDetailList(channelId,agentId,type));
        list.add(register);
        Statistics order=new Statistics();
        order.setCount(channelService.getOrderCount(channelId,agentId,type));
        order.setDiscountPackageList(channelService.getOrderDetailList(channelId,agentId,type,0));
        list.add(order);
        Statistics statistics=new Statistics();
        statistics.setDiscountPackageList(channelService.getOrderList(channelId,agentId,type));
        list.add(statistics);
        result.setData(list);
        return result;
    }

    public String Get(String url, String param) {
        String result = "";
        BufferedReader in = null;
        try {
            String urlNameString = url + "?" + param;
            URL realUrl = new URL(urlNameString);
            // 打开和URL之间的连接
            URLConnection connection = realUrl.openConnection();
            // 设置通用的请求属性
            connection.setRequestProperty("accept", "*/*");
            connection.setRequestProperty("connection", "Keep-Alive");
            connection.setRequestProperty("user-agent",
                    "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
            // 建立实际的连接
            connection.connect();
            // 获取所有响应头字段
            Map<String, List<String>> map = connection.getHeaderFields();
            // 遍历所有的响应头字段
            for (String key : map.keySet()) {
                System.out.println(key + "--->" + map.get(key));
            }
            // 定义 BufferedReader输入流来读取URL的响应
            in = new BufferedReader(new InputStreamReader(
                    connection.getInputStream(),"UTF-8"));
            String line;
            while ((line = in.readLine()) != null) {
                result += line;
            }
        } catch (Exception e) {
            System.out.println("发送GET请求出现异常！" + e);
            e.printStackTrace();
        }
        // 使用finally块来关闭输入流
        finally {
            try {
                if (in != null) {
                    in.close();
                }
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
        return result;
    }

    public String Post(String httpUrl, String param)
    {
        HttpURLConnection connection = null;
        InputStream is = null;
        OutputStream os = null;
        BufferedReader br = null;
        String result = null;
        try {
            URL url = new URL(httpUrl);
            // 通过远程url连接对象打开连接
            connection = (HttpURLConnection) url.openConnection();
            // 设置连接请求方式
            connection.setRequestMethod("POST");
            // 设置连接主机服务器超时时间：15000毫秒
            connection.setConnectTimeout(15000);
            // 设置读取主机服务器返回数据超时时间：60000毫秒
            connection.setReadTimeout(60000);

            // 默认值为：false，当向远程服务器传送数据/写数据时，需要设置为true
            connection.setDoOutput(true);
            // 默认值为：true，当前向远程服务读取数据时，设置为true，该参数可有可无
            connection.setDoInput(true);
            // 设置传入参数的格式:请求参数应该是 name1=value1&name2=value2 的形式。
            connection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");

            // 设置鉴权信息：Authorization: Bearer da3efcbf-0845-4fe3-8aba-ee040be542c0
            connection.setRequestProperty("Authorization", "Bearer da3efcbf-0845-4fe3-8aba-ee040be542c0");

            // 通过连接对象获取一个输出流
            os = connection.getOutputStream();
            // 通过输出流对象将参数写出去/传输出去,它是通过字节数组写出的
            os.write(param.getBytes());
            // 通过连接对象获取一个输入流，向远程读取
            if (connection.getResponseCode() == 200) {

                is = connection.getInputStream();
                // 对输入流对象进行包装:charset根据工作项目组的要求来设置
                br = new BufferedReader(new InputStreamReader(is, "UTF-8"));

                StringBuffer sbf = new StringBuffer();
                String temp = null;
                // 循环遍历一行一行读取数据
                while ((temp = br.readLine()) != null) {
                    sbf.append(temp);
                    sbf.append("\r\n");
                }
                result = sbf.toString();
            }
        } catch (MalformedURLException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            // 关闭资源
            if (null != br) {
                try {
                    br.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (null != os) {
                try {
                    os.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (null != is) {
                try {
                    is.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            // 断开与远程地址url的连接
            connection.disconnect();
        }
        return result;
    }

    public Token getAccessToken(String appID, String appScret) {
        Token token = new Token();
        String url = "https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=" + appID + "&secret="
                + appScret;
        try {
            URL getUrl=new URL(url);
            HttpURLConnection http=(HttpURLConnection)getUrl.openConnection();
            http.setRequestMethod("GET");
            http.setRequestProperty("Content-Type",
                    "application/x-www-form-urlencoded");
            http.setDoOutput(true);
            http.setDoInput(true);


            http.connect();
            InputStream is = http.getInputStream();
            int size = is.available();
            byte[] b = new byte[size];
            is.read(b);

            String message = new String(b, "UTF-8");
            JSONObject json = JSONObject.parseObject(message);


            token.setAccess_token(json.getString("access_token"));
            token.setExpires_in(new Integer(json.getString("expires_in")));
        } catch (MalformedURLException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return token;
    }

    public static String SHA1(String str) {
        try {
            MessageDigest digest = java.security.MessageDigest.getInstance("SHA-1"); //如果是SHA加密只需要将"SHA-1"改成"SHA"即可
            digest.update(str.getBytes());
            byte messageDigest[] = digest.digest();
            // Create Hex String
            StringBuffer hexStr = new StringBuffer();
            // 字节数组转换为 十六进制 数
            for (int i = 0; i < messageDigest.length; i++) {
                String shaHex = Integer.toHexString(messageDigest[i] & 0xFF);
                if (shaHex.length() < 2) {
                    hexStr.append(0);
                }
                hexStr.append(shaHex);
            }
            return hexStr.toString();

        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
        }
        return null;
    }
}
